==> swc-1.3.97.tar.gz: swc-1.3.97/crates/swc_ecma_transforms_proposal/tests/decorators/2022-03-misc/all-decorators/output.js <==
var _initClass, _init_d, _call_f, _call_g, _call_g1, _init_h, _get___h, _set___h, _init_m, _call_o, _call_p, _call_q, _init_r, _get___r, _set___r, _init_a, _init_e, _init_i, _init_n, _initProto, _initStatic;
const dec = ()=>{};
let _Class;
new class extends _identity {
    constructor(){
        super(_Class), _initClass();
    }
    static{
        class Class {
            static{
                ({ e: [_init_m, _call_o, _call_p, _call_q, _init_r, _get___r, _set___r, _init_i, _init_n, _init_d, _call_f, _call_g, _call_g1, _init_h, _get___h, _set___h, _init_a, _init_e, _initProto, _initStatic], c: [_Class, _initClass] } = _apply_decs_2203_r(this, [
                    [
                        dec,
                        7,
                        "j"
                    ],
                    [
                        dec,
                        8,
                        "k"
                    ],
                    [
                        dec,
                        9,
                        "l"
                    ],
                    [
                        dec,
                        6,
                        "m"
                    ],
                    [
                        dec,
                        7,
                        "o",
                        function() {}
                    ],
                    [
                        dec,
                        8,
                        "p",
                        function() {}
                    ],
                    [
                        dec,
                        9,
                        "q",
                        function(v) {}
                    ],
                    [
                        dec,
                        6,
                        "r",
                        function() {
                            return this.#__r;
                        },
                        function(_v) {
                            this.#__r = _v;
                        }
                    ],
                    [
                        dec,
                        5,
                        "i"
                    ],
                    [
                        dec,
                        5,
                        "n",
                        function() {
                            return this.#n;
                        },
                        function(value) {
                            this.#n = value;
                        }
                    ],
                    [
                        dec,
                        2,
                        "b"
                    ],
                    [
                        dec,
                        3,
                        "c"
                    ],
                    [
                        dec,
                        4,
                        "c"
                    ],
                    [
                        dec,
                        1,
                        "d"
                    ],
                    [
                        dec,
                        2,
                        "f",
                        function() {}
                    ],
                    [
                        dec,
                        3,
                        "g",
                        function() {}
                    ],
                    [
                        dec,
                        4,
                        "g",
                        function(v) {}
                    ],
                    [
                        dec,
                        1,
                        "h",
                        function() {
                            return this.#__h;
                        },
                        function(_v) {
                            this.#__h = _v;
                        }
                    ],
                    [
                        dec,
                        0,
                        "a"
                    ],
                    [
                        dec,
                        0,
                        "e",
                        function() {
                            return this.#e;
                        },
                        function(value) {
                            this.#e = value;
                        }
                    ]
                ], [
                    dec
                ]));
                _initStatic(this);
            }
            a = _init_a(this);
            b() {}
            get c() {}
            set c(v) {}
            #___private_d = (_initProto(this), _init_d(this));
            get d() {
                return this.#___private_d;
            }
            set d(_v) {
                this.#___private_d = _v;
            }
            #e = _init_e(this);
            get #f() {
                return _call_f;
            }
            get #g() {
                return _call_g(this);
            }
            set #g(v) {
                return _call_g1(this, v);
            }
            #__h = _init_h(this);
            get #h() {
                return _get___h(this);
            }
            set #h(_v) {
                _set___h(this, _v);
            }
            static i = _init_i(this);
            static j() {}
            static get k() {}
            static set l(v) {}
            static get m() {
                return this.#___private_m;
            }
            static set m(_v) {
                this.#___private_m = _v;
            }
        }
    }
    #___private_m = _init_m(this);
    #n = _init_n(this);
    get #o() {
        return _call_o;
    }
    get #p() {
        return _call_p(this);
    }
    set #q(v) {
        return _call_q(this, v);
    }
    #__r = _init_r(this);
    get #r() {
        return _get___r(this);
    }
    set #r(_v) {
        _set___r(this, _v);
    }
}();

==> swc-1.11.22.tar.gz: swc-1.11.22/crates/swc_ecma_transforms_proposal/tests/decorators/2022-03-misc/all-decorators/output.js <==
var _initClass, _init_d, _call_f, _call_g, _call_g1, _init_h, _get___h, _set___h, _init_m, _call_o, _call_p, _call_q, _init_r, _get___r, _set___r, _init_a, _init_e, _init_i, _init_n, _initProto, _initStatic;
const dec = ()=>{};
let _Class;
new class extends _identity {
    constructor(){
        super(_Class), _initClass();
    }
    static{
        class Class {
            static{
                ({ e: [_init_m, _call_o, _call_p, _call_q, _init_r, _get___r, _set___r, _init_i, _init_n, _init_d, _call_f, _call_g, _call_g1, _init_h, _get___h, _set___h, _init_a, _init_e, _initProto, _initStatic], c: [_Class, _initClass] } = _apply_decs_2203_r(this, [
                    [
                        dec,
                        7,
                        "j"
                    ],
                    [
                        dec,
                        8,
                        "k"
                    ],
                    [
                        dec,
                        9,
                        "l"
                    ],
                    [
                        dec,
                        6,
                        "m"
                    ],
                    [
                        dec,
                        7,
                        "o",
                        function() {}
                    ],
                    [
                        dec,
                        8,
                        "p",
                        function() {}
                    ],
                    [
                        dec,
                        9,
                        "q",
                        function(v) {}
                    ],
                    [
                        dec,
                        6,
                        "r",
                        function() {
                            return this.#__r_4;
                        },
                        function(_v) {
                            this.#__r_4 = _v;
                        }
                    ],
                    [
                        dec,
                        5,
                        "i"
                    ],
                    [
                        dec,
                        5,
                        "n",
                        function() {
                            return this.#n;
                        },
                        function(value) {
                            this.#n = value;
                        }
                    ],
                    [
                        dec,
                        2,
                        "b"
                    ],
                    [
                        dec,
                        3,
                        "c"
                    ],
                    [
                        dec,
                        4,
                        "c"
                    ],
                    [
                        dec,
                        1,
                        "d"
                    ],
                    [
                        dec,
                        2,
                        "f",
                        function() {}
                    ],
                    [
                        dec,
                        3,
                        "g",
                        function() {}
                    ],
                    [
                        dec,
                        4,
                        "g",
                        function(v) {}
                    ],
                    [
                        dec,
                        1,
                        "h",
                        function() {
                            return this.#__h_2;
                        },
                        function(_v) {
                            this.#__h_2 = _v;
                        }
                    ],
                    [
                        dec,
                        0,
                        "a"
                    ],
                    [
                        dec,
                        0,
                        "e",
                        function() {
                            return this.#e;
                        },
                        function(value) {
                            this.#e = value;
                        }
                    ]
                ], [
                    dec
                ]));
                _initStatic(this);
            }
            a = (_initProto(this), _init_a(this));
            b() {}
            get c() {}
            set c(v) {}
            #___private_d_1 = _init_d(this);
            get d() {
                return this.#___private_d_1;
            }
            set d(_v) {
                this.#___private_d_1 = _v;
            }
            #e = _init_e(this);
            get #f() {
                return _call_f;
            }
            get #g() {
                return _call_g(this);
            }
            set #g(v) {
                return _call_g1(this, v);
            }
            #__h_2 = _init_h(this);
            get #h() {
                return _get___h(this);
            }
            set #h(_v) {
                _set___h(this, _v);
            }
            static i = _init_i(this);
            static j() {}
            static get k() {}
            static set l(v) {}
            static get m() {
                return this.#___private_m_3;
            }
            static set m(_v) {
                this.#___private_m_3 = _v;
            }
        }
    }
    #___private_m_3 = _init_m(this);
    #n = _init_n(this);
    get #o() {
        return _call_o;
    }
    get #p() {
        return _call_p(this);
    }
    set #q(v) {
        return _call_q(this, v);
    }
    #__r_4 = _init_r(this);
    get #r() {
        return _get___r(this);
    }
    set #r(_v) {
        _set___r(this, _v);
    }
}();
